==> transmission-2.33.tar.xz: transmission-2.33/macosx/DragOverlayWindow.h <==
/******************************************************************************
 * $Id: DragOverlayWindow.h 11617 2011-01-01 20:42:14Z livings124 $
 *
 * Copyright (c) 2007-2011 Transmission authors and contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *****************************************************************************/

#import <Cocoa/Cocoa.h>
#import <transmission.h>

@interface DragOverlayWindow : NSWindow
{
    tr_session * fLib;
    
    NSViewAnimation * fFadeInAnimation, * fFadeOutAnimation;
}

- (id) initWithLib: (tr_session *) lib forWindow: (NSWindow *) window;

- (void) setTorrents: (NSArray *) files;
- (void) setFile: (NSString *) file;
- (void) setURL: (NSString *) url;

- (void) fadeIn;
- (void) fadeOut;

@end

==> transmission-3.00.tar.xz: transmission-3.00/macosx/DragOverlayWindow.h <==
/******************************************************************************
 * Copyright (c) 2007-2012 Transmission authors and contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *****************************************************************************/

#import <Cocoa/Cocoa.h>

#include <libtransmission/transmission.h>

@interface DragOverlayWindow : NSWindow
{
    tr_session * fLib;

    NSViewAnimation * fFadeInAnimation, * fFadeOutAnimation;
}

- (id) initWithLib: (tr_session *) lib forWindow: (NSWindow *) window;

- (void) setTorrents: (NSArray *) files;
- (void) setFile: (NSString *) file;
- (void) setURL: (NSString *) url;

- (void) fadeIn;
- (void) fadeOut;

@end
